diff --git a/css/global.css b/css/global.css
index 023c8f35..469f6a23 100644
--- a/css/global.css
+++ b/css/global.css
@@ -23,7 +23,7 @@ span.versionInfo{
display: inline-block;
}
-div.OGPVersionArea{
+div.GSPVersionArea{
width: 100%;
position: relative;
}
diff --git a/gsp_api.php b/gsp_api.php
index c398cbc5..2c63e9f2 100644
--- a/gsp_api.php
+++ b/gsp_api.php
@@ -281,7 +281,7 @@ function api_server()
{
$remote_server_id = $_POST['remote_server_id'];
$remote_server = $db->getRemoteServer($remote_server_id);
- $remote = new OGPRemoteLibrary($remote_server['agent_ip'],$remote_server['agent_port'],$remote_server['encryption_key'],$remote_server['timeout']);
+ $remote = new GSPRemoteLibrary($remote_server['agent_ip'],$remote_server['agent_port'],$remote_server['encryption_key'],$remote_server['timeout']);
$status = "200";
$message = $remote->status_chk() == 1?'online':'offline';
}
@@ -290,7 +290,7 @@ function api_server()
{
$remote_server_id = $_POST['remote_server_id'];
$remote_server = $db->getRemoteServer($remote_server_id);
- $remote = new OGPRemoteLibrary($remote_server['agent_ip'],$remote_server['agent_port'],$remote_server['encryption_key'],$remote_server['timeout']);
+ $remote = new GSPRemoteLibrary($remote_server['agent_ip'],$remote_server['agent_port'],$remote_server['encryption_key'],$remote_server['timeout']);
$remote->agent_restart();
$status = "200";
$message = "success";
@@ -488,7 +488,7 @@ function api_user_games()
if(!isPortValid($port))
return array("status" => '309', "message" => "The given port is not a valid port.");
- $remote = new OGPRemoteLibrary($remote_server['agent_ip'],$remote_server['agent_port'],$remote_server['encryption_key'],$remote_server['timeout']);
+ $remote = new GSPRemoteLibrary($remote_server['agent_ip'],$remote_server['agent_port'],$remote_server['encryption_key'],$remote_server['timeout']);
$host_stat = $remote->status_chk();
if($host_stat !== 1)
return array("status" => '310', "message" => "The remote server is offline.");
@@ -581,7 +581,7 @@ function api_user_games()
}
}
- $remote = new OGPRemoteLibrary($game_home['agent_ip'],$game_home['agent_port'],$game_home['encryption_key'],$game_home['timeout']);
+ $remote = new GSPRemoteLibrary($game_home['agent_ip'],$game_home['agent_port'],$game_home['encryption_key'],$game_home['timeout']);
$host_stat = $remote->status_chk();
if($host_stat !== 1)
return array("status" => '310', "message" => "The remote server is offline.");
@@ -957,7 +957,7 @@ function api_gamemanager()
if($server_xml === FALSE)
return array("status" => '305', "message" => "No game configuration found for home_cfg_id #" . $home_cfg_id . ".");
- $remote = new OGPRemoteLibrary($home_info['agent_ip'],$home_info['agent_port'],$home_info['encryption_key'],$home_info['timeout']);
+ $remote = new GSPRemoteLibrary($home_info['agent_ip'],$home_info['agent_port'],$home_info['encryption_key'],$home_info['timeout']);
$host_stat = $remote->status_chk();
if($host_stat !== 1)
return array("status" => '310', "message" => "The remote server is offline.");
@@ -1421,7 +1421,7 @@ function api_litefm()
if($server_xml === FALSE)
return array("status" => '305', "message" => "No game configuration found for home_cfg_id #" . $home_cfg_id . ".");
- $remote = new OGPRemoteLibrary($home_info['agent_ip'],$home_info['agent_port'],$home_info['encryption_key'],$home_info['timeout']);
+ $remote = new GSPRemoteLibrary($home_info['agent_ip'],$home_info['agent_port'],$home_info['encryption_key'],$home_info['timeout']);
$host_stat = $remote->status_chk();
if($host_stat !== 1)
return array("status" => '310', "message" => "The remote server is offline.");
@@ -1514,7 +1514,7 @@ function api_addonsmanager()
if($server_xml === FALSE)
return array("status" => '305', "message" => "No game configuration found for home_cfg_id #" . $home_cfg_id . ".");
- $remote = new OGPRemoteLibrary($home_info['agent_ip'],$home_info['agent_port'],$home_info['encryption_key'],$home_info['timeout']);
+ $remote = new GSPRemoteLibrary($home_info['agent_ip'],$home_info['agent_port'],$home_info['encryption_key'],$home_info['timeout']);
$host_stat = $remote->status_chk();
if($host_stat !== 1)
return array("status" => '310', "message" => "The remote server is offline.");
@@ -1632,7 +1632,7 @@ function api_steam_workshop()
if($server_xml === FALSE)
return array("status" => '305', "message" => "No game configuration found for home_cfg_id #" . $home_cfg_id . ".");
- $remote = new OGPRemoteLibrary($home_info['agent_ip'],$home_info['agent_port'],$home_info['encryption_key'],$home_info['timeout']);
+ $remote = new GSPRemoteLibrary($home_info['agent_ip'],$home_info['agent_port'],$home_info['encryption_key'],$home_info['timeout']);
$host_stat = $remote->status_chk();
if($host_stat !== 1)
return array("status" => '310', "message" => "The remote server is offline.");
diff --git a/home.php b/home.php
index 1fade329..f841a1e0 100644
--- a/home.php
+++ b/home.php
@@ -26,7 +26,7 @@ $db = createDatabaseConnection($db_type, $db_host, $db_user, $db_pass, $db_name,
include_once("includes/lang.php");
if (!$db instanceof GSPDatabase) {
- ogpLang();
+ gspLang();
die(get_lang('no_db_connection'));
}
@@ -37,7 +37,7 @@ if(hasValue($_SESSION['user_id'])){
$settings = $db->getSettings();
@$GLOBALS['panel_language'] = $settings['panel_language'];
-ogpLang();
+gspLang();
require_once("includes/view.php");
$view = new OGPView();
diff --git a/includes/api_functions.php b/includes/api_functions.php
index 496e5b41..3437fb8a 100644
--- a/includes/api_functions.php
+++ b/includes/api_functions.php
@@ -91,7 +91,7 @@ function get_start_cmd($user_info,$remote,$server_xml,$home_info,$mod_id,$ip,$po
$cli_param_data['IP'] = $ip;
$cli_param_data['PORT'] = $port;
$cli_param_data['HOSTNAME'] = $home_info['home_name'];
- $cli_param_data['PID_FILE'] = "ogp_game_startup.pid";
+ $cli_param_data['PID_FILE'] = "gsp_game_startup.pid";
// Linux
if( preg_match("/Linux/", $os) )
diff --git a/includes/database_mysqli.php b/includes/database_mysqli.php
index 0631a244..97921cef 100644
--- a/includes/database_mysqli.php
+++ b/includes/database_mysqli.php
@@ -3762,7 +3762,7 @@ class GSPDatabaseMySQL extends GSPDatabase
case 'server':
require_once('includes/lib_remote.php');
$home_info = $this->getGameHomeWithoutMods($home_id);
- $remote = new OGPRemoteLibrary($home_info['agent_ip'], $home_info['agent_port'], $home_info['encryption_key'], $home_info['timeout']);
+ $remote = new GSPRemoteLibrary($home_info['agent_ip'], $home_info['agent_port'], $home_info['encryption_key'], $home_info['timeout']);
$agent_online = $remote->status_chk() === 1;
if( $agent_online )
{
diff --git a/includes/form_table_class.php b/includes/form_table_class.php
index f9ef27a4..dc0c59b7 100644
--- a/includes/form_table_class.php
+++ b/includes/form_table_class.php
@@ -112,7 +112,7 @@ class FormTable {
print_failure(get_lang_f('invalid_setting_type',$type));
}
- if ( defined("OGP_LANG_".$name."_info") )
+ if ( defined("GSP_LANG_".$name."_info") )
{
echo "
".str_replace("'",'"',get_lang($name."_info"))." | ";
$this->i++;
@@ -128,7 +128,7 @@ class FormTable {
echo " | ";
echo "".$data." | \n";
- if ( defined("OGP_LANG_".$name."_info") )
+ if ( defined("GSP_LANG_".$name."_info") )
{
echo " ".str_replace("'",'"',get_lang($name."_info"))." | \n
\n";
$this->i++;
diff --git a/includes/functions.php b/includes/functions.php
index 5cf4cbd1..2e285c07 100644
--- a/includes/functions.php
+++ b/includes/functions.php
@@ -1047,7 +1047,7 @@ function deleteMysqlAddonDatabasesForGameServerHome($home_id){
if($mysql_db['remote_server_id'] != "0")
{
$remote_server = $db->getRemoteServer($mysql_db['remote_server_id']);
- $remote = new OGPRemoteLibrary($remote_server['agent_ip'],$remote_server['agent_port'],$remote_server['encryption_key'],$remote_server['timeout']);
+ $remote = new GSPRemoteLibrary($remote_server['agent_ip'],$remote_server['agent_port'],$remote_server['encryption_key'],$remote_server['timeout']);
$host_stat = $remote->status_chk();
if($host_stat === 1 )
{
diff --git a/includes/helpers.php b/includes/helpers.php
index 463a9fe0..7f90a812 100644
--- a/includes/helpers.php
+++ b/includes/helpers.php
@@ -4,7 +4,7 @@
*/
// Globals
-$OGPLangPre = "OGP_LANG_";
+$GSPLangPre = "GSP_LANG_";
// Ignore any request with unwanted values at 'm' or 'p'
if( isset($_REQUEST['m']) and !preg_match("/^([a-z]|[0-9]|_|-)+$/i", $_REQUEST['m']) )
@@ -457,12 +457,12 @@ function getGitHubOrganization($gitHubURL){
}
function getOGPLangConstantsJSON(){
- global $OGPLangPre;
+ global $GSPLangPre;
$finalConsts = array();
$consts = get_defined_constants(true);
foreach($consts["user"] as $key => $value){
- if(startsWith($key, $OGPLangPre)){
+ if(startsWith($key, $GSPLangPre)){
$finalConsts[$key] = $value;
}
}
diff --git a/includes/lib_remote.php b/includes/lib_remote.php
index 9c438e2e..3f9a7acc 100644
--- a/includes/lib_remote.php
+++ b/includes/lib_remote.php
@@ -6,12 +6,12 @@
require_once("Crypt/XXTEA.php");
// Screen type for servers
-define("OGP_SCREEN_TYPE_HOME","HOME");
-define("OGP_SCREEN_TYPE_UPDATE","UPDATE");
+define("GSP_SCREEN_TYPE_HOME","HOME");
+define("GSP_SCREEN_TYPE_UPDATE","UPDATE");
define("AGENT_ERROR_NOT_EXECUTABLE",-13);
-class OGPRemoteLibrary
+class GSPRemoteLibrary
{
private $port;
private $host;
diff --git a/includes/navig.php b/includes/navig.php
index 5ad8425c..83c0ecfa 100644
--- a/includes/navig.php
+++ b/includes/navig.php
@@ -78,13 +78,13 @@ function navigation() {
include_once( $include_file );
- if ( !function_exists( 'exec_ogp_module' ) )
+ if ( !function_exists( 'exec_gsp_module' ) )
{
print_failure("Missing module execute function.");
return;
}
- exec_ogp_module();
+ exec_gsp_module();
return;
}
print_failure("Invalid subpage given.");
@@ -94,12 +94,12 @@ function navigation() {
else if ( is_file( MODULES.$_REQUEST['m'].'/'.$_REQUEST['m'].'.php') )
{
include( MODULES.$_REQUEST['m'].'/'.$_REQUEST['m'].'.php');
- if ( !function_exists( 'exec_ogp_module' ) )
+ if ( !function_exists( 'exec_gsp_module' ) )
{
print_failure("Missing module execute function.");
return;
}
- exec_ogp_module();
+ exec_gsp_module();
}
// If files above are not found then we print an error.
else
diff --git a/includes/view.php b/includes/view.php
index e5834bb5..153bafa9 100644
--- a/includes/view.php
+++ b/includes/view.php
@@ -29,7 +29,7 @@ class OGPView {
function menu(){}
function printView($cleared = false, $dataType = "html") {
- global $db, $OGPLangPre;
+ global $db, $GSPLangPre;
if ( is_object($db) && array_key_exists( "GSPDatabase", class_parents($db) ) ) {
$panel_settings = $db->getSettings();
@@ -82,7 +82,7 @@ class OGPView {
// Dump defined constants to json (for language javascript)
$jsonStrConsts = getOGPLangConstantsJSON();
if($jsonStrConsts !== false){
- $this->header_code .= '' . "\n";
+ $this->header_code .= '' . "\n";
}
// Include jQuery, jQuery UI, and our global CSS file in the header code
@@ -197,7 +197,7 @@ class OGPView {
if ( is_object($db) && array_key_exists( "GSPDatabase", class_parents($db) ) ) {
$footer .= "";
+ $footer .= "
".get_lang('copyright')." © GameServer Panel " . date("Y") . " - ".get_lang('all_rights_reserved')." - ".get_lang('show_version')."
" . get_lang('version') . ": ".@$panel_settings['gsp_version']."
";
}
else
{
diff --git a/index.php b/index.php
index 034b53d9..17b7b284 100644
--- a/index.php
+++ b/index.php
@@ -43,7 +43,7 @@ $db = createDatabaseConnection($db_type, $db_host, $db_user, $db_pass, $db_name,
include_once("includes/lang.php");
if (!$db instanceof GSPDatabase) {
- ogpLang();
+ gspLang();
die(get_lang('no_db_connection'));
}
@@ -54,7 +54,7 @@ if(hasValue($_SESSION['user_id'])){
$settings = $db->getSettings();
@$GLOBALS['panel_language'] = $settings['panel_language'];
-ogpLang();
+gspLang();
require_once("includes/view.php");
$view = new OGPView();
diff --git a/modules/TS3Admin/TS3Admin.php b/modules/TS3Admin/TS3Admin.php
index 61e78876..2ea516f3 100644
--- a/modules/TS3Admin/TS3Admin.php
+++ b/modules/TS3Admin/TS3Admin.php
@@ -3,7 +3,7 @@
* Administrative interface for the ts3admin module
*/
-function exec_ogp_module()
+function exec_gsp_module()
{
$templates_folder = 'modules/TS3Admin/templates_c';
if( is_writable( $templates_folder ) )
diff --git a/modules/TS3Admin/templates_c/%%F7^F7F^F7F34188%%header.tpl.php b/modules/TS3Admin/templates_c/%%F7^F7F^F7F34188%%header.tpl.php
index f01433f0..ccc499e9 100644
--- a/modules/TS3Admin/templates_c/%%F7^F7F^F7F34188%%header.tpl.php
+++ b/modules/TS3Admin/templates_c/%%F7^F7F^F7F34188%%header.tpl.php
@@ -3,25 +3,25 @@
- _tpl_vars['lang']['OGP_LANG_js_error']; ?>
+ _tpl_vars['lang']['GSP_LANG_js_error']; ?>
- _tpl_vars['lang']['OGP_LANG_js_ajax_error']; ?>
+ _tpl_vars['lang']['GSP_LANG_js_ajax_error']; ?>
-
-
-
-
-
-
-
-
diff --git a/includes/lang.php b/includes/lang.php
index 219e10ae..1e96e1c4 100644
--- a/includes/lang.php
+++ b/includes/lang.php
@@ -17,11 +17,11 @@ function add_lang_module($lang_module)
{
global $lang_modules;
array_push($lang_modules,$lang_module);
- // Need to reload langs if module is added after the first ogpLang call.
- ogpLang();
+ // Need to reload langs if module is added after the first gspLang call.
+ gspLang();
}
-function ogpLang()
+function gspLang()
{
global $lang_modules;
$locale_files = makefilelist("lang/", ".|..|.svn", true, "folders");
@@ -68,15 +68,15 @@ function ogpLang()
function get_lang($lang_index)
{
- global $OGPLangPre;
+ global $GSPLangPre;
if (defined($lang_index))
{
return constant($lang_index);
}
- if(!startsWith($lang_index, $OGPLangPre)){
- $newLangIndex = $OGPLangPre . $lang_index;
+ if(!startsWith($lang_index, $GSPLangPre)){
+ $newLangIndex = $GSPLangPre . $lang_index;
if (defined($newLangIndex))
{
return constant($newLangIndex);
@@ -89,7 +89,7 @@ function get_lang($lang_index)
function get_lang_f()
{
- global $OGPLangPre;
+ global $GSPLangPre;
$args = func_get_args();
$lang_index = array_shift($args);
@@ -98,8 +98,8 @@ function get_lang_f()
return vsprintf(constant($lang_index),$args);
}
- if(!startsWith($lang_index, $OGPLangPre)){
- $newLangIndex = $OGPLangPre . $lang_index;
+ if(!startsWith($lang_index, $GSPLangPre)){
+ $newLangIndex = $GSPLangPre . $lang_index;
if (defined($newLangIndex))
{
return vsprintf(constant($newLangIndex),$args);